MeltStructure <- function(T,N,ATI1,He,Pr,thourP,thourT,Tsnow,Train,UADJ,MBASE,TIPM,MFMAX,MFMIN,PLWHC,Wi2) {
#####Begin determination of melt structure
#Will return Melt from rain on snow (Mr), Melt during non-rain period (Mnr), Antecedent Temperature Index (ATI) and Heat deficit due to gradient (DelDt)

	#compute some things needed later on
	esat <- 2.7489*10^8*exp(-4278.63/(T+242.792)) #saturate vapor pressure at T[i] (mb)
	Pa = 33.86*(29.9-0.335*He+0.00022*He^2.4) #atmospheric pressure (mb) where He is in meters
	Sv = 0.5*sin((N*2*pi)/366)+0.5 #seasonal variation of non-rain melt factor where N is number of days since March 21st
	Av = 1.0 #Because we are typically south of 54 North
	Mf = thourT/6*(Sv*Av*(MFMAX-MFMIN)+MFMIN) #Non-rain melt factor
	
	#Calculate melt during rain on snow - Mr is melt during rain on snow(mm)
	#Assume snow surface temperature = 0 degrees C, rain ~ air temperature
	#Only compute rain on snow melt when rain is > 1.5 mm/6 hours
	if (Pr > (thourP*0.25)) {
	Mr = -6.12*(10^-10)*thourP*((T+273)^4-273^4)+0.0125*Pr*Train+8.5*UADJ*(thourP/6)*((0.9*esat-6.11)+0.00057*Pa*T)
	}else{
	Mr = 0
	}

	#Non-rain melt
	#Mnr is melt during non-rain periods(mm) 
	if (Pr <= (thourP*0.25) & T > MBASE) {
	Mnr = Mf*(T-MBASE)*thourP/thourT+0.0125*Pr*Train
	}else{
	Mnr = 0
	}

	#Calculate ATI
	#Assume snow surface temperature is equal to 0 or T[i], whichever is less
	#If new snow is greater than 1.5mm/hr, ATI = Tsnow
	if (T > 0) Tsur = 0 else Tsur = T
	if (ATI1 > 0) ATI1 = 0
	TIPMdt = 1.0-(1.0-TIPM)^(thourT/6) #delta temp
	if (Pn > 1.5*(thourP)) ATI2 = Tsnow else ATI2 = ATI1 + TIPMdt*(T-ATI1)
	
	#Compute change in heat deficit due to temperature gradient
	#Gradient in upper layers is estimated as difference between ATI and Tsur
	#When Tsur is greater than ATI, heat deficit is decreasing, the rate of which is determined by the negative melt factor
	DelDt = NMF*(thourP/6)*(Mf/MFMAX)*(ATI2-Tsur)

	#Compute Water equivalent of current timestep
	#Calculate liquid water available at surface of snow from melt and rain, adjust heat deficit
	#Qw = liquid water available at snow surface (mm) <- melt rain + melt non-rain + incoming rain (either Mr or Mnr must be 0)
	if (Mr + Mnr < 0) {
	Qw = 0 + Pr
	}else if(Mr+Mnr < Wi2) {
	Wi2 = Wi2-(Mr+Mnr) 
	Qw = Mr + Mnr + Pr
	}else {
	Qw = Wi2 + Pr
	Wi2 = 0
	}	
Melt_Parm <- c(Wi2,ATI2,Qw,DelDt)	
return(Melt_Parm)
}