CalcRipeness <- function(Wi2,D1,DelDt,DelDp,Wq,ATI2,Qw,PLWHC,S1,thourP,DAYGM) {
	source("CalcTransmission.R")
	source("CalcOutflow.R")
	source("CalcDepth.R")
	
	#Deal with ripeness of snow
	#Wqx = liquid water holding capacity of snow (mm)
	#This is a function of a calibration paramter (a decimal fraction - must be less than 0.4) and the ice portion of the snow
	Wqx = PLWHC*Wi2
	
	#Adjust heat deficit by temperature of new snow and heat transfer gradient in upper layer of snow
	D2 = D1 + DelDp + DelDt #D is in mm
	E = 0
	
if (Wi2 > 0) {
	#Water is outflowing from the snowpack
	#If there is sufficient water to overcome heat deficit and exceed liquid water capacity, snow becomes ripe
	#E[i] is the excess water available for outflow during the current timestep (mm)
	#Wq[i] is the liquid water held by the snow (mm)
	if(Qw + Wq > Wqx + D2) {
		E = Qw + Wq - Wqx - D2 - (PLWHC*D2)
		if (E > Wi2+Wq){
		E = Wi2+Wq
		Wq = 0
		Wi2 = 0
		D2 = 0
		}else{
		Wq = Wqx
		Wi2 = Wi2+D2
		D2 = 0
		}
	}else if (Qw + Wq >= D2){
		#overcome heat deficit but not enough to fill holding capacity
		E = 0
		Wq = Wq + Qw - D2
		D2 = 0
		Wi2 = Wi2 + D2 
	}else{
		E = 0
		Wi2 = Wi2 + Qw
		D2 = D2 - Qw
		Wq = Wq
	}
	
	if (D2 == 0) ATI2 = 0 else ATI2 = ATI2
	As <- 1
	
	if (E > 0) {
		
		if (Wi2 == 0) {
		Out_tot = E
		D2 = 0
		Wt = 0
		Wi2 = 0
		Wqt2 = 0
		E = 0
		Wt=0
		Sfinal = 0
		
		}else{
		
		Trans_Value <- CalcTransmission(Wi2,E,S1,thourP,As)
		Sfinal <- Trans_Value[1]
		Omr_tot <- Trans_Value[2]
		E <- Trans_Value[3]
		Wqt2 = Wq + Sfinal

		Out_Value <- CalcOutflow(thourP,Wi2,Wq,Omr_tot,DAYGM)
		Wi2 = Out_Value[1]
		Out_tot = Out_Value[2]
		Wt = Wi2 + Wqt2
		}	
		
	}else{
		Sfinal = S1
		Omr_tot = 0
		E = 0
		Wqt2 = Wq + Sfinal
		
		Out_Value <- CalcOutflow(thourP,Wi2,Wq,Omr_tot,DAYGM)
		Wi2 = Out_Value[1]
		Out_tot = Out_Value[2]
		Wt = Wi2 + Wqt2
		
	}
}else{
	Out_tot = Qw
	D2 = 0
	Wt = 0
	Wi2 = 0
	Wqt2 = 0
	E = 0
	Wt=0
	Sfinal = 0
	}

Ripe_Parm <- c(Wi2,D2,E,ATI2,Wq,Wqt2,Wt,Out_tot,Sfinal)
return(Ripe_Parm)
}


